BlocMonitor<R extends Bloc<S>, S> class abstract

Callbacks which are sent by the blocs, can be used for debugging or side effects

T is the type of state value bloc is the name of bloc, which sent the event

Constructors

BlocMonitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBroadcast(R bloc, S? state, {String? event}) → void
Called when the bloc broadcasts a new state to the connected builders
onBusy(R bloc, {String? event}) → void
Called whenever the bloc is set to busy
onError(R bloc, dynamic error, {String? event}) → void
Called whenever the bloc encounters an error
onEvent(R bloc, S? currentState, S? update, {String? event}) → void
Called when bloc calls the setState method
onInit(R bloc, S? initState) → void
Called when the bloc is being initialized
onStreamDispose(R bloc) → void
Called when the internal stream of the bloc is being disposed (because it has no more listeners)
onStreamListener(R bloc) → void
Called when a builder starts listening to this bloc's broadcasts
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited