BusyBuilder<T> typedef
BusyBuilder<T> =
Widget Function(BuildContext context, T? data)
This function takes a context and data of type T and returns a widget
Used when bloc updates its state and widget needs to rebuild with new data
Implementation
typedef BusyBuilder<T> = Widget Function(BuildContext context, T? data);