ContextX<S> extension
- on
Properties
- isDisposed → bool
-
Available on BuildContext, provided by the ContextX extension
no setter
Methods
-
bloc<
R extends Bloc< (S> >) → R? -
Available on BuildContext, provided by the ContextX extension
Get a Bloc that exists in an ancestor widget -
blocBuilder<
R extends Bloc< (S> >{Key? key, required DataBuilder< S> onState, BusyBuilder<S> ? onBusy, ErrorBuilder? onError}) → Widget -
Available on BuildContext, provided by the ContextX extension
-
blocState<
R extends Bloc< (S> >) → S? -
Available on BuildContext, provided by the ContextX extension
Get the current Bloc.state from a Bloc that exists in an ancestor widget -
blocValue<
R extends Bloc< (S> >) → S? -
Available on BuildContext, provided by the ContextX extension